@@ -852,10 +852,6 @@ void MainWindow::onWindowStateChanged()
     qDebug() << windowState();
 
     if (!isFullScreen()) {
-        //if (_lastRectInNormalMode.isValid() && !_miniMode && !isMaximized()) {
-            //setGeometry(_lastRectInNormalMode);
-        //}
-
         qApp->restoreOverrideCursor();
         if (_lastCookie > 0) {
             utils::UnInhibitStandby(_lastCookie);
@@ -896,9 +892,13 @@ void MainWindow::onWindowStateChanged()
 #endif
 
     if (!isFullScreen() && !isMaximized()) {
-        if (_movieSwitchedInFsOrMaxed) {
-            setMinimumSize({0, 0});
-            resizeByConstraints(true);
+        if (_movieSwitchedInFsOrMaxed || !_lastRectInNormalMode.isValid()) {
+            if (_mousePressed || _mouseMoved) {
+                _delayedResizeByConstraint = true;
+            } else {
+                setMinimumSize({0, 0});
+                resizeByConstraints(true);
+            }
         }
         _movieSwitchedInFsOrMaxed = false;
     }
@@ -1441,7 +1441,8 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         case ActionFactory::ActionKind::OpenFileList: {
             QStringList filenames = QFileDialog::getOpenFileNames(this, tr("Open File"),
                     QDir::currentPath(),
-                    tr("Movies (%1)").arg(_engine->video_filetypes.join(" ")));
+                    tr("All videos (%1)").arg(_engine->video_filetypes.join(" ")), 0,
+                    QFileDialog::HideNameFilterDetails);
             
             QList<QUrl> urls;
             if (filenames.size()) {
@@ -1457,7 +1458,8 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         case ActionFactory::ActionKind::OpenFile: {
             QString filename = QFileDialog::getOpenFileName(this, tr("Open File"),
                     QDir::currentPath(),
-                    tr("Movies (%1)").arg(_engine->video_filetypes.join(" ")));
+                    tr("All videos (%1)").arg(_engine->video_filetypes.join(" ")), 0,
+                    QFileDialog::HideNameFilterDetails);
             if (QFileInfo(filename).exists()) {
                 play(QUrl::fromLocalFile(filename));
             }
@@ -1552,7 +1554,10 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
                 if (_lastWindowState == Qt::WindowMaximized) {
                     showMaximized();
                 } else {
-                    showNormal();
+                    setWindowState(windowState() & ~Qt::WindowFullScreen);
+                    if (_lastRectInNormalMode.isValid() && !_miniMode && !isMaximized()) {
+                        setGeometry(_lastRectInNormalMode);
+                    }
                 }
             } else {
                 if (!_miniMode && (fromUI || isShortcut)) {
@@ -1904,6 +1909,18 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
             break;
         }
 
+        case ActionFactory::ActionKind::NextFrame: {
+            _engine->nextFrame();
+
+            break;
+        }
+
+        case ActionFactory::ActionKind::PreviousFrame: {
+            _engine->previousFrame();
+
+            break;
+        }
+
         default:
             break;
     }
@@ -1987,7 +2004,7 @@ void MainWindow::handleSettings()
     }
 
     // hack: reset is set to default by QDialog, which makes lineedit's enter
-    // press is responsed by reset button
+    // press is responded by reset button
     auto reset = dsd->findChild<QPushButton*>("SettingsContentReset");
     reset->setDefault(false);
     reset->setAutoDefault(false);
@@ -2297,7 +2314,10 @@ void MainWindow::resizeByConstraints(bool forceCentered)
         sz.scale(geom.width(), geom.height(), Qt::KeepAspectRatio);
     }
 
-    qDebug() << sz;
+    qDebug() << "original: " << size() << "requested: " << sz;
+    if (size() == sz) 
+        return;
+
     if (forceCentered) {
         QRect r;
         r.setSize(sz);
@@ -2351,7 +2371,6 @@ void MainWindow::updateGeometryNotification(const QSize& sz)
 void MainWindow::resizeEvent(QResizeEvent *ev)
 {
     qDebug() << __func__ << geometry();
-    
     if (isFullScreen()) {
         _progIndicator->move(geometry().width() - _progIndicator->width() - 18, 8);
     }
@@ -2401,6 +2420,14 @@ void MainWindow::capturedMousePressEvent(QMouseEvent* me)
 
 void MainWindow::capturedMouseReleaseEvent(QMouseEvent* me)
 {
+    if (_delayedResizeByConstraint) {
+        _delayedResizeByConstraint = false;
+
+        QTimer::singleShot(0, [=]() {
+            this->setMinimumSize({0, 0});
+            this->resizeByConstraints(true);
+        });
+    }
 }
 
 static bool _afterDblClick = false;
@@ -2466,7 +2493,7 @@ void MainWindow::mouseReleaseEvent(QMouseEvent *ev)
         _playState->setState(DImageButton::Normal);
     }
 
-    // dtk has a bug, DImageButton propagates mouseReleaseEvent event when it responsed to.
+    // dtk has a bug, DImageButton propagates mouseReleaseEvent event when it responded to.
     if (!insideResizeArea(ev->globalPos()) && !_mouseMoved && !insideToolsArea(ev->pos())) {
         if (_playlist->state() != PlaylistWidget::Opened)
             _delayedMouseReleaseTimer.start(120);
@@ -2487,11 +2514,9 @@ void MainWindow::mouseMoveEvent(QMouseEvent *ev)
 {
     _mouseMoved = true;
 
-//#ifndef USE_DXCB
     if (windowState() == Qt::WindowNoState || isMaximized()) {
         Utility::startWindowSystemMove(this->winId());
     }
-//#endif
     QWidget::mouseMoveEvent(ev);
 }
 
