@@ -299,8 +299,10 @@ bool PlayerEngine::loadSubtitle(const QFileInfo& fi)
     }
 
     if (_current->loadSubtitle(fi)) {
+#ifndef _LIBDMR_
         MovieConfiguration::get().append2ListUrl(pif.url, ConfigKnownKey::ExternalSubs,
                 fi.canonicalFilePath());
+#endif
         return true;
     }
     return false;
@@ -453,9 +455,28 @@ void PlayerEngine::savePlaybackPosition()
     _current->savePlaybackPosition();
 }
 
+void PlayerEngine::nextFrame()
+{
+    if (!_current) return;
+    _current->nextFrame();
+}
+
+void PlayerEngine::previousFrame()
+{
+    if (!_current) return;
+    _current->previousFrame();
+}
+
 void PlayerEngine::play()
 {
-    if (state() == CoreState::Idle && _playlist->count()) {
+    if (!_current || !_playlist->count()) return;
+
+    if (state() == CoreState::Paused && 
+            getBackendProperty("keep-open").toBool() &&
+            getBackendProperty("eof-reached").toBool()) {
+        stop();
+        next();
+    } else if (state() == CoreState::Idle) {
         next();
     }
 }
@@ -623,13 +644,13 @@ QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl>& urls)
 QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl>& urls)
 {
     qDebug() << urls;
-    //NOTE: take care of loop, we dont recursive, it seems safe now
+    //NOTE: take care of loop, we don't recursive, it seems safe now
     QList<QUrl> valids;
     for (const auto& url: urls) {
         if (url.isLocalFile()) {
             QFileInfo fi(url.toLocalFile());
             if (!fi.exists()) {
-                qDebug() << url << "dont exists";
+                qDebug() << url << "don't exist";
                 continue;
             }
 
@@ -704,7 +725,7 @@ void PlayerEngine::resizeEvent(QResizeEvent* re)
 {
     bool rounded = !window()->isFullScreen() && !window()->isMaximized();
 
-#ifndef USE_DXCB
+#if !defined(USE_DXCB) && !defined(_LIBDMR_)
     if (rounded) {
         QPixmap shape(size());
         shape.fill(Qt::transparent);
@@ -722,4 +743,19 @@ void PlayerEngine::resizeEvent(QResizeEvent* re)
 #endif
 }
 
+void PlayerEngine::setBackendProperty(const QString& name, const QVariant& val)
+{
+    if (_current) {
+        _current->setProperty(name, val);
+    }
+}
+
+QVariant PlayerEngine::getBackendProperty(const QString& name)
+{
+    if (_current) {
+        return _current->getProperty(name);
+    }
+    return QVariant();
+}
+
 } // end of namespace dmr
