@@ -2,13 +2,13 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="85"/>
-        <location filename="../main.cpp" line="117"/>
+        <location filename="../main.cpp" line="86"/>
+        <location filename="../main.cpp" line="118"/>
         <source>Deepin Movie</source>
         <translation>Deepin Movie</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="86"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
         <translation>O Deepin Movie é um reprodutor de vídeo completo e bem concebido, com um design simples e sem rebordo. Suporta reprodução local e remota de média em múltiplos formatos de vídeo.</translation>
     </message>
@@ -466,20 +466,20 @@
     <name>dmr::MainWindow</name>
     <message>
         <location filename="../common/mainwindow.cpp" line="785"/>
-        <location filename="../common/mainwindow.cpp" line="2271"/>
-        <location filename="../common/mainwindow.cpp" line="2366"/>
+        <location filename="../common/mainwindow.cpp" line="2279"/>
+        <location filename="../common/mainwindow.cpp" line="2374"/>
         <source>Deepin Movie</source>
         <translation>Deepin Movie</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1794"/>
+        <location filename="../common/mainwindow.cpp" line="1796"/>
         <source>Load successfully</source>
         <translation>Carregado com sucesso</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1794"/>
+        <location filename="../common/mainwindow.cpp" line="1796"/>
         <source>Load failed</source>
         <translation>Carregamento falhou</translation>
     </message>
@@ -500,89 +500,89 @@
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="1442"/>
-        <location filename="../common/mainwindow.cpp" line="1458"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <location filename="../common/mainwindow.cpp" line="1459"/>
+        <location filename="../common/mainwindow.cpp" line="1791"/>
         <source>Open File</source>
         <translation>Abrir Ficheiro</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="1444"/>
-        <location filename="../common/mainwindow.cpp" line="1460"/>
-        <source>Movies (%1)</source>
-        <translation>Filmes (%1)</translation>
+        <location filename="../common/mainwindow.cpp" line="1461"/>
+        <source>All videos (%1)</source>
+        <translation>Todos os vídeos (%1)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1657"/>
+        <location filename="../common/mainwindow.cpp" line="1659"/>
         <source>Muted</source>
         <translation>Silenciada</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1660"/>
-        <location filename="../common/mainwindow.cpp" line="1672"/>
-        <location filename="../common/mainwindow.cpp" line="1682"/>
-        <location filename="../common/mainwindow.cpp" line="1689"/>
+        <location filename="../common/mainwindow.cpp" line="1662"/>
+        <location filename="../common/mainwindow.cpp" line="1674"/>
+        <location filename="../common/mainwindow.cpp" line="1684"/>
+        <location filename="../common/mainwindow.cpp" line="1691"/>
         <source>Volume: %1%</source>
         <translation>Volume: %1%</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1754"/>
-        <location filename="../common/mainwindow.cpp" line="1762"/>
+        <location filename="../common/mainwindow.cpp" line="1756"/>
+        <location filename="../common/mainwindow.cpp" line="1764"/>
         <source>Subtitle %1: %2s</source>
         <translation>Legendas %1: %2s</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1755"/>
-        <location filename="../common/mainwindow.cpp" line="1763"/>
+        <location filename="../common/mainwindow.cpp" line="1757"/>
+        <location filename="../common/mainwindow.cpp" line="1765"/>
         <source>delayed</source>
         <translation>Atrasado</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1755"/>
-        <location filename="../common/mainwindow.cpp" line="1763"/>
+        <location filename="../common/mainwindow.cpp" line="1757"/>
+        <location filename="../common/mainwindow.cpp" line="1765"/>
         <source>advanced</source>
         <translation>Avançado</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1770"/>
-        <location filename="../common/mainwindow.cpp" line="1777"/>
-        <location filename="../common/mainwindow.cpp" line="1784"/>
+        <location filename="../common/mainwindow.cpp" line="1772"/>
+        <location filename="../common/mainwindow.cpp" line="1779"/>
+        <location filename="../common/mainwindow.cpp" line="1786"/>
         <source>Speed: %1x</source>
         <translation>Velocidade: %1x</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1791"/>
+        <location filename="../common/mainwindow.cpp" line="1793"/>
         <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
         <translation>Legendas (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1853"/>
+        <location filename="../common/mainwindow.cpp" line="1855"/>
         <source>View</source>
         <translation>Ver</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1864"/>
+        <location filename="../common/mainwindow.cpp" line="1866"/>
         <source>Movie Screenshot</source>
         <translation>Captura de Ecrã de Filme</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1865"/>
+        <location filename="../common/mainwindow.cpp" line="1867"/>
         <source>Saved to</source>
         <translation>Guardado em</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1879"/>
-        <location filename="../common/mainwindow.cpp" line="1950"/>
+        <location filename="../common/mainwindow.cpp" line="1881"/>
+        <location filename="../common/mainwindow.cpp" line="1952"/>
         <source>The screenshot is saved</source>
         <translation>A captura de ecrã foi guardada.</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1879"/>
+        <location filename="../common/mainwindow.cpp" line="1881"/>
         <source>The screenshot is failed to save</source>
         <translation>Falha a gravar captura de ecrã</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="2033"/>
-        <location filename="../common/mainwindow.cpp" line="2720"/>
+        <location filename="../common/mainwindow.cpp" line="2039"/>
+        <location filename="../common/mainwindow.cpp" line="2728"/>
         <source>Invalid file: %1</source>
         <translation>Ficheiro inválido: %1</translation>
     </message>
@@ -590,27 +590,27 @@
 <context>
     <name>dmr::MovieInfoDialog</name>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
+        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
         <source>File Type:</source>
         <translation>Tipo de ficheiro:</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="122"/>
+        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
         <source>Resolution:</source>
         <translation>Resolução:</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="123"/>
+        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
         <source>File Size:</source>
         <translation>Tamanho do ficheiro:</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="124"/>
+        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
         <source>Duration:</source>
         <translation>Duração:</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="129"/>
+        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
         <source>File Path:</source>
         <translation>Caminho do ficheiro:</translation>
     </message>
@@ -618,8 +618,8 @@
 <context>
     <name>dmr::MpvProxy</name>
     <message>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1001"/>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1019"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1017"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1035"/>
         <source>[internal]</source>
         <translation>[interno]</translation>
     </message>
